@@ -1,6 +1,6 @@
 # ==========================================================================
 #
-# ZoneMinder Visca Control Protocol Module, $Date: 2008-07-25 10:48:16 +0100 (Fri, 25 Jul 2008) $, $Revision: 2612 $
+# ZoneMinder Visca Control Protocol Module, $Date$, $Revision$
 # Copyright (C) 2001-2008  Philip Coombes
 #
 # This program is free software; you can redistribute it and/or
@@ -41,7 +41,7 @@ our $VERSION = $ZoneMinder::Base::VERSION;
 #
 # ==========================================================================
 
-use ZoneMinder::Debug qw(:all);
+use ZoneMinder::Logger qw(:all);
 
 use Time::HiRes qw( usleep );
 
@@ -103,7 +103,7 @@ sub close
 
 sub printMsg
 {
-    if ( zmDbgLevel() > 0 )
+    if ( logDebugging() )
     {
         my $self = shift;
         my $msg = shift;
