@@ -1,5 +1,5 @@
 //
-// ZoneMinder Core Interfaces, $Date: 2011-02-15 11:18:41 +0000 (Tue, 15 Feb 2011) $, $Revision: 3301 $
+// ZoneMinder Core Interfaces, $Date$, $Revision$
 // $Copyright$
 // 
 // This program is free software; you can redistribute it and/or
@@ -20,20 +20,11 @@
 #ifndef ZM_H
 #define ZM_H
 
-extern "C"
-{
-#include "zm_debug.h"
-}
-
 #include "zm_config.h"
-
-extern "C"
-{
-#if !HAVE_DECL_ROUND
-double round(double);
-#endif
-}
+#include "zm_logger.h"
 
 #include <stdint.h>
 
+extern const char* self;
+
 #endif // ZM_H
