@@ -1,5 +1,5 @@
 //
-// ZoneMinder Core Interfaces, $Date: 2009-01-21 17:37:39 +0000 (Wed, 21 Jan 2009) $, $Revision: 2718 $
+// ZoneMinder Core Interfaces, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -133,6 +133,9 @@ public:
 	void AddFrames( int n_frames, Image **images, struct timeval **timestamps );
 	void AddFrame( Image *image, struct timeval timestamp, int score=0, Image *alarm_frame=NULL );
 
+private:
+	void AddFramesInternal( int n_frames, int start_frame, Image **images, struct timeval **timestamps );
+
 public:
     static const char *getSubPath( struct tm *time )
     {
