@@ -1,5 +1,5 @@
 //
-// ZoneMinder Local Camera Class Interface, $Date: 2011-02-15 21:59:06 +0000 (Tue, 15 Feb 2011) $, $Revision: 3302 $
+// ZoneMinder Local Camera Class Interface, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -22,6 +22,7 @@
 
 #include "zm.h"
 #include "zm_camera.h"
+#include "zm_image.h"
 
 #if ZM_HAS_V4L
 
@@ -63,57 +64,55 @@ protected:
 #if ZM_HAS_V4L1
     struct V4L1Data
     {
-	    int				    active_frame;
-	    video_mbuf		    frames;
-	    video_mmap		    *buffers;
-	    unsigned char	    *bufptr;
+        int active_frame;
+        video_mbuf frames;
+        video_mmap *buffers;
+        unsigned char *bufptr;
     };
 #endif // ZM_HAS_V4L1
 
 protected:
-	std::string             device;
-	int		                channel;
-	int	                    standard;
-    int                     palette;
-
-    bool                    device_prime;
-    bool                    channel_prime;
-    int                     channel_index;
+	std::string device;
+	int channel;
+	int standard;
+	int palette;
+	bool device_prime;
+	bool channel_prime;
+	int channel_index;
+	unsigned int extras;
+	
+	unsigned int conversion_type; /* 0 = no conversion needed, 1 = use libswscale, 2 = zm internal conversion, 3 = jpeg decoding */
+	convert_fptr_t conversion_fptr; /* Pointer to conversion function used */
+	
+	uint32_t AutoSelectFormat(int p_colours);
 
 protected:
-	static int				camera_count;
-	static int				channel_count;
-    static int              channels[VIDEO_MAX_FRAME];
-    static int              standards[VIDEO_MAX_FRAME];
-
-	static int				vid_fd;
-
-    static int              v4l_version;
+	static int camera_count;
+	static int channel_count;
+	static int channels[VIDEO_MAX_FRAME];
+	static int standards[VIDEO_MAX_FRAME];
+	static int vid_fd;
+	static int v4l_version;
 
 #if ZM_HAS_V4L2
-    static V4L2Data         v4l2_data;
+	static V4L2Data         v4l2_data;
 #endif // ZM_HAS_V4L2
 #if ZM_HAS_V4L1
-    static V4L1Data         v4l1_data;
+	static V4L1Data         v4l1_data;
 #endif // ZM_HAS_V4L1
 
 #if HAVE_LIBSWSCALE
-    PixelFormat             imagePixFormat;
-    PixelFormat             capturePixFormat;
-    static AVFrame          **capturePictures;
+	static AVFrame    	**capturePictures;
+	PixelFormat       	imagePixFormat;
+	PixelFormat       	capturePixFormat;
+	struct SwsContext 	*imgConversionContext;
+	AVFrame           	*tmpPicture;    
 #endif // HAVE_LIBSWSCALE
 
-	static unsigned char	*y_table;
-	static signed char		*uv_table;
-	static short			*r_v_table;
-	static short			*g_v_table;
-	static short			*g_u_table;
-	static short			*b_u_table;
-
-    static LocalCamera      *last_camera;
+	static LocalCamera      *last_camera;
 
 public:
-	LocalCamera( int p_id, const std::string &device, int p_channel, int p_format, const std::string &p_method, int p_width, int p_height, int p_palette, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture );
+	LocalCamera( int p_id, const std::string &device, int p_channel, int p_format, const std::string &p_method, int p_width, int p_height, int p_colours, int p_palette, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture, unsigned int p_extras = 0);
 	~LocalCamera();
 
 	void Initialise();
@@ -124,6 +123,7 @@ public:
 	int Channel() const { return( channel ); }
 	int Standard() const { return( standard ); }
 	int Palette() const { return( palette ); }
+	int Extras() const { return( extras ); }
 
 	int Brightness( int p_brightness=-1 );
 	int Hue( int p_hue=-1 );
