@@ -1,5 +1,5 @@
 /*
- * ZoneMinder Logger Implementation, $Date: 2011-06-28 12:07:35 +0100 (Tue, 28 Jun 2011) $, $Revision: 3474 $
+ * ZoneMinder Logger Implementation, $Date$, $Revision$
  * Copyright (C) 2001-2008 Philip Coombes
  * 
  * This program is free software; you can redistribute it and/or
@@ -22,14 +22,12 @@
 #include "zm_config.h"
 #include "zm_utils.h"
 
+#include <unistd.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/time.h>
 #include <syslog.h>
-#ifdef HAVE_SYSCALL_H
-#include <syscall.h>
-#endif // HAVE_SYSCALL_H
 #include <signal.h>
 #include <stdarg.h>
 #include <errno.h>
@@ -40,6 +38,7 @@ Logger *Logger::smInstance = 0;
 Logger::StringMap Logger::smCodes;
 Logger::IntMap Logger::smSyslogPriorities;
 
+#if 0
 static void subtractTime( struct timeval * const tp1, struct timeval * const tp2 )
 {
     tp1->tv_sec -= tp2->tv_sec;
@@ -53,6 +52,7 @@ static void subtractTime( struct timeval * const tp1, struct timeval * const tp2
         tp1->tv_usec = tp1->tv_usec - tp2->tv_usec;
     }
 }
+#endif
 
 void Logger::usrHandler( int sig )
 {
@@ -178,7 +178,7 @@ void Logger::initialise( const std::string &id, const Options &options )
     if ( config.log_debug )
     {
         StringVector targets = split( config.log_debug_target, "|" );
-        for ( int i = 0; i < targets.size(); i++ )
+        for ( unsigned int i = 0; i < targets.size(); i++ )
         {
             const std::string &target = targets[i];
             if ( target == mId || target == "_"+mId || target == "_"+mIdRoot || target == "_"+mIdRoot || target == "" )
