@@ -1,5 +1,5 @@
 //
-// ZoneMinder Monitor Class Interfaces, $Date: 2011-02-15 21:59:06 +0000 (Tue, 15 Feb 2011) $, $Revision: 3302 $
+// ZoneMinder Monitor Class Interfaces, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -20,14 +20,21 @@
 #ifndef ZM_MONITOR_H
 #define ZM_MONITOR_H
 
+#include <vector>
+#include <sstream>
+
 #include "zm.h"
 #include "zm_coord.h"
 #include "zm_image.h"
+#include "zm_rgb.h"
 #include "zm_zone.h"
 #include "zm_event.h"
 #include "zm_camera.h"
 
+#include "zm_image_analyser.h"
+
 #include <sys/time.h>
+#include <stdint.h>
 
 #define SIGNAL_CAUSE "Signal"
 #define MOTION_CAUSE "Motion"
@@ -85,43 +92,64 @@ protected:
 
 	typedef enum { CLOSE_TIME, CLOSE_IDLE, CLOSE_ALARM } EventCloseMode;
 
+	/* sizeof(SharedData) expected to be 336 bytes on 32bit and 64bit */
 	typedef struct
 	{
-		int size;
-		bool valid;
-		bool active;
-		bool signal;
-		State state;
-		int last_write_index;
-		int last_read_index;
-		time_t last_write_time;
-		time_t last_read_time;
-		int last_event;
-		int action;
-		int brightness;
-		int hue;
-		int colour;
-		int contrast;
-		int alarm_x;
-		int alarm_y;
-		char control_state[256];
+		uint32_t size;             	/* +0    */
+		uint32_t last_write_index; 	/* +4    */ 
+		uint32_t last_read_index;  	/* +8    */
+		uint32_t state;            	/* +12   */
+		uint32_t last_event;       	/* +16   */
+		uint32_t action;           	/* +20   */
+		int32_t brightness;        	/* +24   */
+		int32_t hue;               	/* +28   */
+		int32_t colour;            	/* +32   */
+		int32_t contrast;          	/* +36   */
+		int32_t alarm_x;           	/* +40   */
+		int32_t alarm_y;           	/* +44   */
+		uint8_t valid;             	/* +48   */
+		uint8_t active;            	/* +49   */
+		uint8_t signal;            	/* +50   */
+		uint8_t format;            	/* +51   */
+		uint32_t imagesize;        	/* +52   */
+		uint32_t epadding1;        	/* +56   */
+		uint32_t epadding2;        	/* +60   */
+		/* 
+		** This keeps 32bit time_t and 64bit time_t identical and compatible as long as time is before 2038.
+		** Shared memory layout should be identical for both 32bit and 64bit and is multiples of 16.
+		*/	
+		union {                    	/* +64    */
+		      time_t last_write_time;
+		      uint64_t extrapad1;
+		};
+		union {                    	/* +72   */
+		      time_t last_read_time;
+		      uint64_t extrapad2;
+		};
+		uint8_t control_state[256];	/* +80   */
+		
 	} SharedData;
 
 	typedef enum { TRIGGER_CANCEL, TRIGGER_ON, TRIGGER_OFF } TriggerState;
+	
+	/* sizeof(TriggerData) expected to be 560 on 32bit & and 64bit */
 	typedef struct
 	{
-		int size;
-		TriggerState trigger_state;
-		int trigger_score;
+		uint32_t size;
+		uint32_t trigger_state;
+		uint32_t trigger_score;
+		uint32_t padding;
 		char trigger_cause[32];
 		char trigger_text[256];
 		char trigger_showtext[256];
 	} TriggerData;
 
+	/* sizeof(Snapshot) expected to be 16 bytes on 32bit and 32 bytes on 64bit */
 	struct Snapshot
 	{
 		struct timeval	*timestamp;
 		Image	*image;
+		void* padding;
 	};
 
 	class MonitorLink
@@ -139,11 +167,11 @@ protected:
 #else // ZM_MEM_MAPPED
         int             shm_id;
 #endif // ZM_MEM_MAPPED
-		int				mem_size;
+		unsigned long				mem_size;
 		unsigned char	*mem_ptr;
 
-		SharedData		*shared_data;
-		TriggerData		*trigger_data;
+		volatile SharedData	*shared_data;
+		volatile TriggerData	*trigger_data;
 
 		int				last_state;
 		int				last_event;
@@ -187,6 +215,7 @@ protected:
 	unsigned int    width;				    // Normally the same as the camera, but not if partly rotated
 	unsigned int    height;				    // Normally the same as the camera, but not if partly rotated
 	Orientation		orientation;		    // Whether the image has to be rotated at all
+	unsigned int	deinterlacing;
 	int				brightness;			    // The statically saved brightness of the camera
 	int				contrast;			    // The statically saved contrast of the camera
 	int				hue;				    // The statically saved hue of the camera
@@ -206,11 +235,12 @@ protected:
 	int				alarm_frame_count;	    // How many alarm frames are required before an event is triggered
 	int				fps_report_interval;    // How many images should be captured/processed between reporting the current FPS
 	int				ref_blend_perc;		    // Percentage of new image going into reference image.
+	int				alarm_ref_blend_perc;		    // Percentage of new image going into reference image during alarm.
 	bool			track_motion;		    // Whether this monitor tries to track detected motion 
     Rgb             signal_check_colour;    // The colour that the camera will emit when no video signal detected
 
 	double			fps;
-	Image			image;
+	Image			delta_image;
 	Image			ref_image;
 
 	Purpose			purpose;			    // What this monitor has been created to do
@@ -234,13 +264,14 @@ protected:
 #else // ZM_MEM_MAPPED
     int             shm_id;
 #endif // ZM_MEM_MAPPED
-	int				mem_size;
+	unsigned long				mem_size;
 	unsigned char	*mem_ptr;
 
 	SharedData		*shared_data;
 	TriggerData		*trigger_data;
 
 	Snapshot		*image_buffer;
+	Snapshot		next_buffer; /* Used by four field deinterlacing */
 
 	Camera			*camera;
 
@@ -249,11 +280,15 @@ protected:
 	int				n_zones;
 	Zone			**zones;
 
+   int iDoNativeMotDet;
+
 	int				n_linked_monitors;
 	MonitorLink		**linked_monitors;
 
 public:
-	Monitor( int p_id, const char *p_name, int p_function, bool p_enabled, const char *p_linked_monitors, Camera *p_camera, int p_orientation, const char *p_event_prefix, const char *p_label_format, const Coord &p_label_coord, int p_image_buffer_count, int p_warmup_count, int p_pre_event_count, int p_post_event_count, int p_stream_replay_buffer, int p_alarm_frame_count, int p_section_length, int p_frame_skip, int p_capture_delay, int p_alarm_capture_delay, int p_fps_report_interval, int p_ref_blend_perc, bool p_track_motion, Rgb p_signal_check_colour, Purpose p_purpose, int p_n_zones=0, Zone *p_zones[]=0 );
+// OurCheckAlarms seems to be unused. Check it on zm_monitor.cpp for more info.
+//bool OurCheckAlarms( Zone *zone, const Image *pImage );
+	Monitor( int p_id, const char *p_name, int p_function, bool p_enabled, const char *p_linked_monitors, Camera *p_camera, int p_orientation, unsigned int p_deinterlacing, const char *p_event_prefix, const char *p_label_format, const Coord &p_label_coord, int p_image_buffer_count, int p_warmup_count, int p_pre_event_count, int p_post_event_count, int p_stream_replay_buffer, int p_alarm_frame_count, int p_section_length, int p_frame_skip, int p_capture_delay, int p_alarm_capture_delay, int p_fps_report_interval, int p_ref_blend_perc, int p_alarm_ref_blend_perc, bool p_track_motion, Rgb p_signal_check_colour, Purpose p_purpose, int p_n_zones=0, Zone *p_zones[]=0 );
 	~Monitor();
 
 	void AddZones( int p_n_zones, Zone *p_zones[] );
@@ -300,7 +335,9 @@ public:
 
 	unsigned int Width() const { return( width ); }
 	unsigned int Height() const { return( height ); }
-    unsigned int Colours() const { return( camera->Colours() ); }
+	unsigned int Colours() const { return( camera->Colours() ); }
+	unsigned int SubpixelOrder() const { return( camera->SubpixelOrder() ); }
+      
  
 	State GetState() const;
 	int GetImage( int index=-1, int scale=100 ) const;
@@ -314,7 +351,7 @@ public:
 	void ForceAlarmOn( int force_score, const char *force_case, const char *force_text="" );
 	void ForceAlarmOff();
 	void CancelForced();
-	TriggerState GetTriggerState() const { return( trigger_data?trigger_data->trigger_state:TRIGGER_CANCEL ); }
+	TriggerState GetTriggerState() const { return( (TriggerState)(trigger_data?trigger_data->trigger_state:TRIGGER_CANCEL )); }
 
 	void actionReload();
 	void actionEnable();
@@ -342,6 +379,8 @@ public:
 	}
 
 	unsigned int DetectMotion( const Image &comp_image, Event::StringSet &zoneSet );
+   // DetectBlack seems to be unused. Check it on zm_monitor.cpp for more info.
+   //unsigned int DetectBlack( const Image &comp_image, Event::StringSet &zoneSet );
 	bool CheckSignal( const Image *image );
 	bool Analyse();
 	void DumpImage( Image *dump_image ) const;
