@@ -1,5 +1,5 @@
 /*
- * ZoneMinder MPEG class implementation, $Date: 2011-05-15 21:38:51 +0100 (Sun, 15 May 2011) $, $Revision: 3338 $
+ * ZoneMinder MPEG class implementation, $Date$, $Revision$
  * Copyright (C) 2001-2008 Philip Coombes
  * 
  * This program is free software; you can redistribute it and/or
@@ -21,9 +21,31 @@
 #include <string.h>
 
 #include "zm.h"
+#include "zm_rgb.h"
 #include "zm_mpeg.h"
 
 #if HAVE_LIBAVCODEC
+extern "C" {
+#include <libavutil/mathematics.h>
+}
+
+#if LIBAVFORMAT_VERSION_INT >= AV_VERSION_INT(54, 1, 0)
+static int encode_frame(AVCodecContext *c, AVFrame *frame)
+{
+    AVPacket pkt = { 0 };
+    int ret, got_output;
+
+    av_init_packet(&pkt);
+    av_init_packet(&pkt);
+    ret = avcodec_encode_video2(c, &pkt, frame, &got_output);
+    if (ret < 0)
+        return ret;
+
+    ret = pkt.size;
+    av_free_packet(&pkt);
+    return ret;
+}
+#endif
 
 bool VideoStream::initialised = false;
 
@@ -68,16 +90,56 @@ void VideoStream::SetupFormat( const char *p_filename, const char *p_format )
 	snprintf( ofc->filename, sizeof(ofc->filename), "%s", filename );
 }
 
-void VideoStream::SetupCodec( int colours, int width, int height, int bitrate, double frame_rate )
+void VideoStream::SetupCodec( int colours, int subpixelorder, int width, int height, int bitrate, double frame_rate )
 {
-	pf = (colours==1?PIX_FMT_GRAY8:PIX_FMT_RGB24);
+	/* ffmpeg format matching */
+	switch(colours) {
+	  case ZM_COLOUR_RGB24:
+	  {
+	    if(subpixelorder == ZM_SUBPIX_ORDER_BGR) {
+	      /* BGR subpixel order */
+	      pf = PIX_FMT_BGR24;
+	    } else {
+	      /* Assume RGB subpixel order */
+	      pf = PIX_FMT_RGB24;
+	    }
+	    break;
+	  }
+	  case ZM_COLOUR_RGB32:
+	  {
+	    if(subpixelorder == ZM_SUBPIX_ORDER_ARGB) {
+	      /* ARGB subpixel order */
+	      pf = PIX_FMT_ARGB;
+	    } else if(subpixelorder == ZM_SUBPIX_ORDER_ABGR) {
+	      /* ABGR subpixel order */
+	      pf = PIX_FMT_ABGR;
+	    } else if(subpixelorder == ZM_SUBPIX_ORDER_BGRA) {
+	      /* BGRA subpixel order */
+	      pf = PIX_FMT_BGRA;
+	    } else {
+	      /* Assume RGBA subpixel order */
+	      pf = PIX_FMT_RGBA;
+	    }
+	    break;
+	  }
+	  case ZM_COLOUR_GRAY8:
+	    pf = PIX_FMT_GRAY8;
+	    break;
+	  default:
+	    Panic("Unexpected colours: %d",colours);
+	    break;
+	}
 
 	/* add the video streams using the default format codecs
 	   and initialize the codecs */
 	ost = NULL;
 	if (of->video_codec != CODEC_ID_NONE)
 	{
+#if LIBAVFORMAT_VERSION_INT < AV_VERSION_INT(53, 4, 0)
 		ost = av_new_stream(ofc, 0);
+#else
+      ost = avformat_new_stream(ofc, 0);
+#endif
 		if (!ost)
 		{
 			Panic( "Could not alloc stream" );
@@ -130,7 +192,11 @@ void VideoStream::SetParameters()
 {
 	/* set the output parameters (must be done even if no
 	   parameters). */
+#if LIBAVFORMAT_VERSION_INT < AV_VERSION_INT(53, 4, 0)
 	if ( av_set_parameters(ofc, NULL) < 0 )
+#else
+	if ( avformat_write_header(ofc, NULL) < 0 )
+#endif
 	{
 		Panic( "Invalid output format parameters" );
 	}
@@ -139,7 +205,7 @@ void VideoStream::SetParameters()
 
 const char *VideoStream::MimeType() const
 {
-	for ( int i = 0; i < sizeof(mime_data)/sizeof(*mime_data); i++ )
+	for ( unsigned int i = 0; i < sizeof(mime_data)/sizeof(*mime_data); i++ )
 	{
 		if ( strcmp( format, mime_data[i].format ) == 0 )
 		{
@@ -176,7 +242,11 @@ void VideoStream::OpenStream()
 		}
 
 		/* open the codec */
+#if LIBAVFORMAT_VERSION_INT < AV_VERSION_INT(53, 7, 0)
 		if ( avcodec_open(c, codec) < 0 )
+#else
+      if ( avcodec_open2(c, codec, 0) < 0 )
+#endif
 		{
 			Panic( "Could not open codec" );
 		}
@@ -188,7 +258,7 @@ void VideoStream::OpenStream()
 			Panic( "Could not allocate opicture" );
 		}
 		int size = avpicture_get_size( c->pix_fmt, c->width, c->height);
-		uint8_t *opicture_buf = (uint8_t *)malloc(size);
+		uint8_t *opicture_buf = (uint8_t *)av_malloc(size);
 		if ( !opicture_buf )
 		{
 			av_free(opicture);
@@ -196,7 +266,7 @@ void VideoStream::OpenStream()
 		}
 		avpicture_fill( (AVPicture *)opicture, opicture_buf, c->pix_fmt, c->width, c->height );
 
-		/* if the output format is not RGB24, then a temporary RGB24
+		/* if the output format is not identical to the input format, then a temporary
 		   picture is needed too. It is then converted to the required
 		   output format */
 		tmp_opicture = NULL;
@@ -208,7 +278,7 @@ void VideoStream::OpenStream()
 				Panic( "Could not allocate temporary opicture" );
 			}
 			int size = avpicture_get_size( pf, c->width, c->height);
-			uint8_t *tmp_opicture_buf = (uint8_t *)malloc(size);
+			uint8_t *tmp_opicture_buf = (uint8_t *)av_malloc(size);
 			if (!tmp_opicture_buf)
 			{
 				av_free( tmp_opicture );
@@ -222,9 +292,9 @@ void VideoStream::OpenStream()
 	if ( !(of->flags & AVFMT_NOFILE) )
 	{
 #if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(51,2,1)
-		if ( avio_open(&ofc->pb, filename, URL_WRONLY) < 0 )
+		if ( avio_open(&ofc->pb, filename, AVIO_FLAG_WRITE) < 0 )
 #else
-		if ( url_fopen(&ofc->pb, filename, URL_WRONLY) < 0 )
+		if ( url_fopen(&ofc->pb, filename, AVIO_FLAG_WRITE) < 0 )
 #endif
 		{
 			Fatal( "Could not open '%s'", filename );
@@ -241,10 +311,14 @@ void VideoStream::OpenStream()
 	}
 
 	/* write the stream header, if any */
+#if LIBAVFORMAT_VERSION_INT < AV_VERSION_INT(53, 4, 0)
 	av_write_header(ofc);
+#else
+	avformat_write_header(ofc, NULL);
+#endif
 }
 
-VideoStream::VideoStream( const char *filename, const char *format, int bitrate, double frame_rate, int colours, int width, int height )
+VideoStream::VideoStream( const char *filename, const char *format, int bitrate, double frame_rate, int colours, int subpixelorder, int width, int height )
 {
 	if ( !initialised )
 	{
@@ -252,7 +326,7 @@ VideoStream::VideoStream( const char *filename, const char *format, int bitrate,
 	}
 
 	SetupFormat( filename, format );
-	SetupCodec( colours, width, height, bitrate, frame_rate );
+	SetupCodec( colours, subpixelorder, width, height, bitrate, frame_rate );
 	SetParameters();
 }
 
@@ -280,7 +354,7 @@ VideoStream::~VideoStream()
 	av_write_trailer(ofc);
 	
 	/* free the streams */
-	for( int i = 0; i < ofc->nb_streams; i++)
+	for( unsigned int i = 0; i < ofc->nb_streams; i++)
 	{
 		av_freep(&ofc->streams[i]);
 	}
@@ -303,7 +377,7 @@ VideoStream::~VideoStream()
 	av_free(ofc);
 }
 
-double VideoStream::EncodeFrame( uint8_t *buffer, int buffer_size, bool add_timestamp, unsigned int timestamp )
+double VideoStream::EncodeFrame( const uint8_t *buffer, int buffer_size, bool add_timestamp, unsigned int timestamp )
 {
 #ifdef HAVE_LIBSWSCALE
     static struct SwsContext *img_convert_ctx = 0;
@@ -337,7 +411,7 @@ double VideoStream::EncodeFrame( uint8_t *buffer, int buffer_size, bool add_time
         }
         sws_scale( img_convert_ctx, tmp_opicture->data, tmp_opicture->linesize, 0, c->height, opicture->data, opicture->linesize );
 #else // HAVE_LIBSWSCALE
-		img_convert( (AVPicture *)opicture, c->pix_fmt, (AVPicture *)tmp_opicture, pf, c->width, c->height );
+		Fatal("swscale is required for MPEG mode");
 #endif // HAVE_LIBSWSCALE
 	}
 	else
@@ -371,7 +445,12 @@ double VideoStream::EncodeFrame( uint8_t *buffer, int buffer_size, bool add_time
 	{
 		if ( add_timestamp )
 			ost->pts.val = timestamp;
+#if LIBAVFORMAT_VERSION_INT < AV_VERSION_INT(54, 1, 0) // NEXTIME
 		int out_size = avcodec_encode_video(c, video_outbuf, video_outbuf_size, opicture_ptr);
+#else
+      int out_size = encode_frame(c, opicture_ptr);
+
+#endif
 		if ( out_size > 0 )
 		{
 #if ZM_FFMPEG_048
