@@ -1,5 +1,5 @@
 //
-// ZoneMinder Remote Camera Class Implementation, $Date: 2009-05-28 09:47:59 +0100 (Thu, 28 May 2009) $, $Revision: 2905 $
+// ZoneMinder Remote Camera Class Implementation, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -21,8 +21,8 @@
 
 #include "zm_utils.h"
 
-RemoteCamera::RemoteCamera( int p_id, const std::string &p_protocol, const std::string &p_host, const std::string &p_port, const std::string &p_path, int p_width, int p_height, int p_palette, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture ) :
-    Camera( p_id, REMOTE_SRC, p_width, p_height, p_palette, p_brightness, p_contrast, p_hue, p_colour, p_capture ),
+RemoteCamera::RemoteCamera( int p_id, const std::string &p_protocol, const std::string &p_host, const std::string &p_port, const std::string &p_path, int p_width, int p_height, int p_colours, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture ) :
+    Camera( p_id, REMOTE_SRC, p_width, p_height, p_colours, ZM_SUBPIX_ORDER_DEFAULT_FOR_COLOUR(p_colours), p_brightness, p_contrast, p_hue, p_colour, p_capture ),
     protocol( p_protocol ),
     host( p_host ),
     port( p_port ),
@@ -35,6 +35,10 @@ RemoteCamera::RemoteCamera( int p_id, const std::string &p_protocol, const std::
 
 RemoteCamera::~RemoteCamera()
 {
+	if(hp != NULL) {
+    		freeaddrinfo(hp);
+		hp = NULL;
+	}
 }
 
 void RemoteCamera::Initialise()
@@ -61,15 +65,15 @@ void RemoteCamera::Initialise()
 		auth64 = base64Encode( auth );
 	}
 
-	if ( !hp )
+	struct addrinfo hints;
+	memset(&hints, 0, sizeof(hints));
+	hints.ai_family = AF_UNSPEC;
+	hints.ai_socktype = SOCK_STREAM;
+
+	int ret = getaddrinfo(host.c_str(), port.c_str(), &hints, &hp);
+	if ( ret != 0 )
 	{
-		if ( !(hp = gethostbyname(host.c_str())) )
-		{
-			Fatal( "Can't gethostbyname(%s): %s", host.c_str(), strerror(h_errno) );
-		}
-		memcpy((char *)&sa.sin_addr, (char *)hp->h_addr, hp->h_length);
-		sa.sin_family = hp->h_addrtype;
-		sa.sin_port = htons(atoi(port.c_str()));
+		Fatal( "Can't getaddrinfo(%s port %s): %s", host.c_str(), port.c_str(), gai_strerror(ret) );
 	}
 }
 
