@@ -1,5 +1,5 @@
 //
-// ZoneMinder Remote Camera Class Implementation, $Date: 2011-07-27 17:08:48 +0100 (Wed, 27 Jul 2011) $, $Revision: 3484 $
+// ZoneMinder Remote Camera Class Implementation, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -24,6 +24,7 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <errno.h>
+#include <netdb.h>
 
 RemoteCameraHttp::RemoteCameraHttp( int p_id, const std::string &p_method, const std::string &p_host, const std::string &p_port, const std::string &p_path, int p_width, int p_height, int p_colours, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture ) :
     RemoteCamera( p_id, "http", p_host, p_port, p_path, p_width, p_height, p_colours, p_brightness, p_contrast, p_hue, p_colour, p_capture )
@@ -87,22 +88,34 @@ void RemoteCameraHttp::Initialise()
 
 int RemoteCameraHttp::Connect()
 {
-    if ( sd < 0 )
+    struct addrinfo *p;
+
+    for(p = hp; p != NULL; p = p->ai_next)
     {
-        sd = socket( hp->h_addrtype, SOCK_STREAM, 0 );
+        sd = socket( p->ai_family, p->ai_socktype, p->ai_protocol );
         if ( sd < 0 )
         {
-            Error( "Can't create socket: %s", strerror(errno) );
-            return( -1 );
+            Warning("Can't create socket: %s", strerror(errno) );
+            continue;
         }
 
-        if ( connect( sd, (struct sockaddr *)&sa, sizeof(sa) ) < 0 )
+        if ( connect( sd, p->ai_addr, p->ai_addrlen ) < 0 )
         {
-            Error( "Can't connect to remote camera: %s", strerror(errno) );
-            Disconnect();
-            return( -1 );
+            close(sd);
+            sd = -1;
+            Warning("Can't connect to remote camera: %s", strerror(errno) );
+            continue;
         }
+
+	/* If we got here, we must have connected successfully */
+	break;
     }
+
+    if(p == NULL) {
+	    Error("Unable to connect to the remote camera, aborting");
+	    return( -1 );
+    }
+
     Debug( 3, "Connected to host, socket = %d", sd );
     return( sd );
 }
@@ -177,7 +190,7 @@ int RemoteCameraHttp::ReadData( Buffer &buffer, int bytes_expected )
     do
     {
         static unsigned char temp_buffer[ZM_NETWORK_BUFSIZ];
-        int bytes_to_read = total_bytes_to_read>sizeof(temp_buffer)?sizeof(temp_buffer):total_bytes_to_read;
+        int bytes_to_read = (unsigned int)total_bytes_to_read>(unsigned int)sizeof(temp_buffer)?sizeof(temp_buffer):total_bytes_to_read;
         int bytes_read = read( sd, temp_buffer, bytes_to_read );
 
         if ( bytes_read < 0)
@@ -428,7 +441,7 @@ int RemoteCameraHttp::GetResponse()
 
                     if ( content_length )
                     {
-                        while ( buffer.size() < content_length )
+                        while ( (long)buffer.size() < content_length )
                         {
                             int buffer_len = ReadData( buffer );
                             if ( buffer_len == 0 )
@@ -550,10 +563,10 @@ int RemoteCameraHttp::GetResponse()
             boundary_match_len = strlen( boundary_match );
 
         static int n_headers;
-        static char *headers[32];
+        //static char *headers[32];
 
         static int n_subheaders;
-        static char *subheaders[32];
+        //static char *subheaders[32];
 
         static char *http_header;
         static char *connection_header;
@@ -565,7 +578,6 @@ int RemoteCameraHttp::GetResponse()
     
         static char http_version[16];
         static char status_code[16];
-        static int status;
         static char status_mesg[256];
         static char connection_type[32];
         static int content_length;
@@ -587,7 +599,6 @@ int RemoteCameraHttp::GetResponse()
 
                     http_version[0] = '\0';
                     status_code [0]= '\0';
-                    status = 0;
                     status_mesg [0]= '\0';
                     connection_type [0]= '\0';
                     content_length = 0;
@@ -645,7 +656,8 @@ int RemoteCameraHttp::GetResponse()
                         Debug( 6, "%s", header_ptr );
                         if ( (crlf = mempbrk( header_ptr, "\r\n", header_len )) )
                         {
-                            headers[n_headers++] = header_ptr;
+                            //headers[n_headers++] = header_ptr;
+                            n_headers++;
 
                             if ( !http_header && (strncasecmp( header_ptr, http_match, http_match_len ) == 0) )
                             {
@@ -857,7 +869,8 @@ int RemoteCameraHttp::GetResponse()
 
                         if ( (crlf = mempbrk( subheader_ptr, "\r\n", subheader_len )) )
                         {
-                            subheaders[n_subheaders++] = subheader_ptr;
+                            //subheaders[n_subheaders++] = subheader_ptr;
+                            n_subheaders++;
 
                             if ( !boundary_header && (strncasecmp( subheader_ptr, content_boundary, content_boundary_len ) == 0) )
                             {
@@ -960,7 +973,7 @@ int RemoteCameraHttp::GetResponse()
 
                     if ( content_length )
                     {
-                        while ( buffer.size() < content_length )
+                        while ( (long)buffer.size() < content_length )
                         {
                             //int buffer_len = ReadData( buffer, content_length-buffer.size() );
                             int buffer_len = ReadData( buffer );
@@ -1102,7 +1115,7 @@ int RemoteCameraHttp::Capture( Image &image )
     {
         case JPEG :
         {
-            if ( !image.DecodeJpeg( buffer.extract( content_length ), content_length ) )
+            if ( !image.DecodeJpeg( buffer.extract( content_length ), content_length, colours, subpixelorder ) )
             {
                 Error( "Unable to decode jpeg" );
                 Disconnect();
@@ -1112,13 +1125,13 @@ int RemoteCameraHttp::Capture( Image &image )
         }
         case X_RGB :
         {
-            if ( content_length != image.Size() )
+            if ( content_length != (long)image.Size() )
             {
                 Error( "Image length mismatch, expected %d bytes, content length was %d", image.Size(), content_length );
                 Disconnect();
                 return( -1 );
             }
-            image.Assign( width, height, colours, buffer );
+            image.Assign( width, height, colours, subpixelorder, buffer, imagesize );
             break;
         }
         case X_RGBZ :
@@ -1129,7 +1142,7 @@ int RemoteCameraHttp::Capture( Image &image )
                 Disconnect();
                 return( -1 );
             }
-            image.Assign( width, height, colours, buffer );
+            image.Assign( width, height, colours, subpixelorder, buffer, imagesize );
             break;
         }
         default :
