@@ -1,5 +1,5 @@
 //
-// ZoneMinder Remote RTSP Camera Class Interface, $Date: 2009-05-28 09:47:59 +0100 (Thu, 28 May 2009) $, $Revision: 2905 $
+// ZoneMinder Remote RTSP Camera Class Interface, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -41,16 +41,28 @@ protected:
 	int rtcp_sd;
 
 	Buffer buffer;
+    Buffer lastSps;
+    Buffer lastPps;
 
     RtspThread::RtspMethod method;
 
     RtspThread *rtspThread;
 
-    AVFormatContext *formatContext;
-    AVCodec *codec;
-    AVCodecContext *codecContext;
-    AVFrame *picture;
     int frameCount;
+    
+#if HAVE_LIBAVFORMAT
+    AVFormatContext     *mFormatContext;
+    int                 mVideoStreamId;
+    AVCodecContext      *mCodecContext;
+    AVCodec             *mCodec;
+    AVFrame             *mRawFrame; 
+    AVFrame             *mFrame;
+    PixelFormat         imagePixFormat;
+#endif // HAVE_LIBAVFORMAT
+
+#if HAVE_LIBSWSCALE
+	struct SwsContext   *mConvertContext;
+#endif
 
 public:
 	RemoteCameraRtsp( int p_id, const std::string &method, const std::string &host, const std::string &port, const std::string &path, int p_width, int p_height, int p_colours, int p_brightness, int p_contrast, int p_hue, int p_colour, bool p_capture );
