@@ -1,5 +1,5 @@
 //
-// ZoneMinder RTP Source Class Implementation, $Date: 2010-07-04 19:00:35 +0100 (Sun, 04 Jul 2010) $, $Revision: 3087 $
+// ZoneMinder RTP Source Class Implementation, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -24,12 +24,19 @@
 
 #include <arpa/inet.h>
 
-RtpSource::RtpSource( int id, const std::string &localHost, int localPortBase, const std::string &remoteHost, int remotePortBase, uint32_t ssrc, uint16_t seq, uint32_t rtpClock, uint32_t rtpTime ) :
+#if LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(54,25,0)
+    #define _AVCODECID AVCodecID
+#else
+    #define _AVCODECID CodecID
+#endif
+
+RtpSource::RtpSource( int id, const std::string &localHost, int localPortBase, const std::string &remoteHost, int remotePortBase, uint32_t ssrc, uint16_t seq, uint32_t rtpClock, uint32_t rtpTime, _AVCODECID codecId ) :
     mId( id ),
     mSsrc( ssrc ),
     mLocalHost( localHost ),
     mRemoteHost( remoteHost ),
     mRtpClock( rtpClock ),
+    mCodecId( codecId ),
     mFrame( 65536 ),
     mFrameCount( 0 ),
     mFrameGood( true ),
@@ -61,6 +68,9 @@ RtpSource::RtpSource( int id, const std::string &localHost, int localPortBase, c
     mLastSrTimeReal = tvZero();
     mLastSrTimeNtp = tvZero();
     mLastSrTimeRtp = 0;
+    
+    if(mCodecId != CODEC_ID_H264 && mCodecId != CODEC_ID_MPEG4)
+        Warning( "The device is using a codec that may not be supported. Do not be surprised if things don't work." );
 }
 
 void RtpSource::init( uint16_t seq )
@@ -253,15 +263,63 @@ bool RtpSource::handlePacket( const unsigned char *packet, size_t packetLen )
 {
     const RtpDataHeader *rtpHeader;
     rtpHeader = (RtpDataHeader *)packet;
+	int rtpHeaderSize = 12 + rtpHeader->cc * 4;
+    // No need to check for nal type as non fragmented packets already have 001 start sequence appended
+    bool h264FragmentEnd = (mCodecId == CODEC_ID_H264) && (packet[rtpHeaderSize+1] & 0x40);
+    bool thisM = rtpHeader->m || h264FragmentEnd;
 
     if ( updateSeq( ntohs(rtpHeader->seqN) ) )
     {
-        Hexdump( 4, packet+sizeof(RtpDataHeader), 16 );
+        Hexdump( 4, packet+rtpHeaderSize, 16 );
+
         if ( mFrameGood )
-            mFrame.append( packet+sizeof(RtpDataHeader), packetLen-sizeof(RtpDataHeader) ); 
+        {
+            int extraHeader = 0;
+            
+            if( mCodecId == CODEC_ID_H264 )
+            {
+                int nalType = (packet[rtpHeaderSize] & 0x1f);
+                
+                switch (nalType)
+                {
+                    case 24:
+                    {
+                        extraHeader = 2;
+                        break;
+                    }
+                    case 25: case 26: case 27:
+                    {
+                        extraHeader = 3;
+                        break;
+                    }
+                    // FU-A and FU-B
+                    case 28: case 29:
+                    {
+                        // Is this NAL the first NAL in fragmentation sequence
+                        if ( packet[rtpHeaderSize+1] & 0x80 )
+                        {
+                            // Now we will form new header of frame
+                            mFrame.append( "\x0\x0\x1\x0", 4 );
+                            // Reconstruct NAL header from FU headers
+                            *(mFrame+3) = (packet[rtpHeaderSize+1] & 0x1f) |
+                                          (packet[rtpHeaderSize] & 0xe0);
+                        }
+                    
+                        extraHeader = 2;
+                        break;
+                    }
+                }
+                
+                // Append NAL frame start code
+                if ( !mFrame.size() )
+                    mFrame.append( "\x0\x0\x1", 3 );
+            }
+            mFrame.append( packet+rtpHeaderSize+extraHeader, packetLen-rtpHeaderSize-extraHeader ); 
+        }
+
         Hexdump( 4, mFrame.head(), 16 );
 
-        if ( rtpHeader->m )
+        if ( thisM )
         {
             if ( mFrameGood )
             {
@@ -297,10 +355,13 @@ bool RtpSource::handlePacket( const unsigned char *packet, size_t packetLen )
         mFrameGood = false;
         mFrame.clear();
     }
-    if ( rtpHeader->m )
+    if ( thisM )
     {
         mFrameGood = true;
+        prevM = true;
     }
+    else
+		prevM = false;
 
     updateJitter( rtpHeader );
 
@@ -323,3 +384,5 @@ bool RtpSource::getFrame( Buffer &buffer )
     Debug( 3, "Copied %d bytes", buffer.size() );
     return( true );
 }
+
+#undef _AVCODECID
\ No newline at end of file
