@@ -1,5 +1,5 @@
 //
-// ZoneMinder RTP Source Class Interface, $Date: 2010-07-04 19:09:44 +0100 (Sun, 04 Jul 2010) $, $Revision: 3088 $
+// ZoneMinder RTP Source Class Interface, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -21,12 +21,19 @@
 #define ZM_RTP_SOURCE_H
 
 #include "zm_buffer.h"
+#include "zm_ffmpeg.h"
 #include "zm_thread.h"
 
 #include <sys/time.h>
 #include <stdint.h>
 #include <string>
 
+#if LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(54,25,0)
+    #define _AVCODECID AVCodecID
+#else
+    #define _AVCODECID CodecID
+#endif
+
 struct RtpDataHeader;
 
 class RtpSource
@@ -81,9 +88,12 @@ private:
     uint32_t mLostPackets;
     uint8_t  mLostFraction;
 
+    _AVCODECID mCodecId;
+
     Buffer mFrame;
     int mFrameCount;
     bool mFrameGood;
+    bool prevM;
     ThreadData<bool> mFrameReady;
     ThreadData<bool> mFrameProcessed;
 
@@ -91,7 +101,8 @@ private:
     void init( uint16_t seq );
 
 public:
-    RtpSource( int id, const std::string &localHost, int localPortBase, const std::string &remoteHost, int remotePortBase, uint32_t ssrc, uint16_t seq, uint32_t rtpClock, uint32_t rtpTime );
+    RtpSource( int id, const std::string &localHost, int localPortBase, const std::string &remoteHost, int remotePortBase, uint32_t ssrc, uint16_t seq, uint32_t rtpClock, uint32_t rtpTime, _AVCODECID codecId );
+    
     bool updateSeq( uint16_t seq );
     void updateJitter( const RtpDataHeader *header );
     void updateRtcpData( uint32_t ntpTimeSecs, uint32_t ntpTimeFrac, uint32_t rtpTime );
@@ -176,4 +187,6 @@ public:
     }
 };
 
+#undef _AVCODECID
+
 #endif // ZM_RTP_SOURCE_H
