@@ -1,5 +1,5 @@
 //
-// ZoneMinder RTSP Class Implementation, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
+// ZoneMinder RTSP Class Implementation, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -330,9 +330,16 @@ int RtspThread::run()
 
     uint32_t rtpClock = 0;
     std::string trackUrl = mUrl;
+    
+    #if LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(54,25,0)
+    enum AVCodecID codecId;
+    #else
+    enum CodecID codecId;
+    #endif
+    
     if ( mFormatContext->nb_streams >= 1 )
     {
-        for ( int i = 0; i < mFormatContext->nb_streams; i++ )
+        for ( unsigned int i = 0; i < mFormatContext->nb_streams; i++ )
         {
             SessionDescriptor::MediaDescriptor *mediaDesc = sessDesc->getStream( i );
 #if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(51,2,1)
@@ -343,6 +350,7 @@ int RtspThread::run()
             {
                 trackUrl += "/"+mediaDesc->getControlUrl();
                 rtpClock = mediaDesc->getClock();
+                codecId = mFormatContext->streams[i]->codec->codec_id;
                 // Hackery pokery
                 //rtpClock = mFormatContext->streams[i]->codec->sample_rate;
                 break;
@@ -500,7 +508,7 @@ int RtspThread::run()
     {
         case RTP_UNICAST :
         {
-            RtpSource *source = new RtpSource( mId, "", localPorts[0], mHost, remotePorts[0], ssrc, seq, rtpClock, rtpTime );
+            RtpSource *source = new RtpSource( mId, "", localPorts[0], mHost, remotePorts[0], ssrc, seq, rtpClock, rtpTime, codecId );
             mSources[ssrc] = source;
             RtpDataThread rtpDataThread( *this, *source );
             RtpCtrlThread rtpCtrlThread( *this, *source );
@@ -545,7 +553,7 @@ int RtspThread::run()
         case RTP_RTSP :
         case RTP_RTSP_HTTP :
         {
-            RtpSource *source = new RtpSource( mId, "", remoteChannels[0], mHost, remoteChannels[0], ssrc, seq, rtpClock, rtpTime );
+            RtpSource *source = new RtpSource( mId, "", remoteChannels[0], mHost, remoteChannels[0], ssrc, seq, rtpClock, rtpTime, codecId );
             mSources[ssrc] = source;
             // These never actually run
             RtpDataThread rtpDataThread( *this, *source );
@@ -576,13 +584,15 @@ int RtspThread::run()
                 {
                     if ( buffer[0] == '$' )
                     {
+                	if ( buffer.size() < 4 )
+                	    break;
                         unsigned char channel = buffer[1];
                         unsigned short len = ntohs( *((unsigned short *)(buffer+2)) );
 
                         Debug( 4, "Got %d bytes left, expecting %d byte packet on channel %d", buffer.size(), len, channel );
-                        if ( buffer.size() < (len+4) )
+                        if ( (unsigned short)buffer.size() < (len+4) )
                         {
-                            Debug( 4, "Missing %zd bytes, rereading", (len+4)-nBytes );
+                            Debug( 4, "Missing %d bytes, rereading", (len+4)-buffer.size() );
                             break;
                         }
                         if ( channel == remoteChannels[0] )
@@ -594,8 +604,10 @@ int RtspThread::run()
                         }
                         else if ( channel == remoteChannels[1] )
                         {
-                            len = ntohs( *((unsigned short *)(buffer+2)) );
-                            Debug( 4, "Got %zd bytes on control channel %d", nBytes, channel );
+//                            len = ntohs( *((unsigned short *)(buffer+2)) );
+//                            Debug( 4, "Got %d bytes on control channel %d", nBytes, channel );
+                            Debug( 4, "Got %d bytes on control channel %d, packet length is %d", buffer.size(), channel, len );
+                            Hexdump( 4, (char *)buffer, 16 );
                             rtpCtrlThread.recvPackets( buffer+4, len );
                         }
                         else
@@ -669,7 +681,7 @@ int RtspThread::run()
         }
         case RTP_MULTICAST :
         {
-            RtpSource *source = new RtpSource( mId, localHost, localPorts[0], mHost, remotePorts[0], ssrc, seq, rtpClock, rtpTime );
+            RtpSource *source = new RtpSource( mId, localHost, localPorts[0], mHost, remotePorts[0], ssrc, seq, rtpClock, rtpTime, codecId );
             mSources[ssrc] = source;
             RtpDataThread rtpDataThread( *this, *source );
             RtpCtrlThread rtpCtrlThread( *this, *source );
