@@ -41,7 +41,11 @@ protected:
         int payloadType;
         const char payloadName[6];
         enum AVMediaType codecType;
+#if LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(54,25,0)
+        enum AVCodecID codecId;
+#else
         enum CodecID codecId;
+#endif
         int clockRate;
         int autoChannels;
     };
@@ -50,7 +54,12 @@ protected:
     {
         const char payloadName[32];
         enum AVMediaType codecType;
+#if LIBAVCODEC_VERSION_INT >= AV_VERSION_INT(54,25,0)
+        enum AVCodecID codecId;
+#else   
         enum CodecID codecId;
+#endif  
+
         //int clockRate;
         //int autoChannels;
     };
@@ -94,6 +103,7 @@ public:
         int mClock;
         int mWidth;
         int mHeight;
+        std::string mSprops;
 
         ConnInfo *mConnInfo;
 
@@ -162,6 +172,14 @@ public:
             return( mHeight );
         }
 
+	void setSprops(const std::string props)
+	{
+		mSprops = props;
+	}
+	const std::string getSprops() const
+	{
+		return ( mSprops );
+	}
         const double getFrameRate() const
         {
             return( mFrameRate );
@@ -207,7 +225,7 @@ public:
     }
     MediaDescriptor *getStream( int index )
     {
-        if ( index < 0 || index >= mMediaList.size() )
+        if ( index < 0 || (unsigned int)index >= mMediaList.size() )
             return( 0 );
         return( mMediaList[index] );
     }
