@@ -1,5 +1,5 @@
 //
-// ZoneMinder Thread Class Interface, $Date: 2009-06-03 09:10:02 +0100 (Wed, 03 Jun 2009) $, $Revision: 2906 $
+// ZoneMinder Thread Class Interface, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -20,14 +20,19 @@
 #ifndef ZM_THREAD_H
 #define ZM_THREAD_H
 
+#include <unistd.h>
 #include <pthread.h>
+#include <unistd.h>
+#ifdef HAVE_SYS_SYSCALL_H
+#include <sys/syscall.h>
+#endif // HAVE_SYS_SYSCALL_H
 #include "zm_exception.h"
 #include "zm_utils.h"
 
 class ThreadException : public Exception
 {
 public:
-    ThreadException( const std::string &message ) : Exception( stringtf( "(%d) "+message, (long int)syscall(224) ) )
+    ThreadException( const std::string &message ) : Exception( stringtf( "(%d) "+message, (long int)syscall(SYS_gettid) ) )
     {
     }
 };
@@ -146,38 +151,38 @@ private:
     mutable Condition mCondition;
 
 public:
-    ThreadData() : mCondition( mMutex )
+    __attribute__((used)) ThreadData() : mCondition( mMutex )
     {
     }
-    ThreadData( T value ) : mValue( value ), mCondition( mMutex )
+    __attribute__((used)) ThreadData( T value ) : mValue( value ), mCondition( mMutex )
     {
     }
     //~ThreadData() {}
 
-    operator T() const
+    __attribute__((used)) operator T() const
     {
         return( getValue() );
     }
-    const T operator=( const T value )
+    __attribute__((used)) const T operator=( const T value )
     {
         return( setValue( value ) );
     }
 
-    const T getValueImmediate() const
+    __attribute__((used)) const T getValueImmediate() const
     {
         return( mValue );
     }
-    T setValueImmediate( const T value )
+    __attribute__((used)) T setValueImmediate( const T value )
     {
         return( mValue = value );
     }
-    const T getValue() const;
-    T setValue( const T value );
-    const T getUpdatedValue() const;
-    const T getUpdatedValue( double secs ) const;
-    const T getUpdatedValue( int secs ) const;
-    void updateValueSignal( const T value );
-    void updateValueBroadcast( const T value );
+    __attribute__((used)) const T getValue() const;
+    __attribute__((used)) T setValue( const T value );
+    __attribute__((used)) const T getUpdatedValue() const;
+    __attribute__((used)) const T getUpdatedValue( double secs ) const;
+    __attribute__((used)) const T getUpdatedValue( int secs ) const;
+    __attribute__((used)) void updateValueSignal( const T value );
+    __attribute__((used)) void updateValueBroadcast( const T value );
 };
 
 class Thread
@@ -200,12 +205,12 @@ protected:
 
     pid_t id() const
     {
-        return( (pid_t)syscall(224) );
+        return( (pid_t)syscall(SYS_gettid) );
     }
     void exit( int status = 0 )
     {
         //INFO( "Exiting" );
-        pthread_exit( (void *)status );
+        pthread_exit( (void *)&status );
     }
     static void *mThreadFunc( void *arg );
 
