@@ -1,5 +1,5 @@
 //
-// ZoneMinder General Utility Functions, $Date: 2009-05-28 09:47:59 +0100 (Thu, 28 May 2009) $, $Revision: 2905 $
+// ZoneMinder General Utility Functions, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -20,6 +20,8 @@
 #ifndef ZM_UTILS_H
 #define ZM_UTILS_H
 
+#include <time.h>
+#include <sys/time.h>
 #include <string>
 #include <vector>
 
@@ -43,4 +45,10 @@ inline int min( int a, int b )
     return( a<=b?a:b );
 }
 
+void ssedetect();
+void* sse2_aligned_memcpy(void* dest, const void* src, size_t bytes);
+void timespec_diff(struct timespec *start, struct timespec *end, struct timespec *diff);
+
+extern unsigned int sseversion;
+
 #endif // ZM_UTILS_H
