@@ -1,5 +1,5 @@
 //
-// ZoneMinder Zone Class Interfaces, $Date: 2008-07-25 10:33:23 +0100 (Fri, 25 Jul 2008) $, $Revision: 2611 $
+// ZoneMinder Zone Class Interfaces, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -77,7 +77,7 @@ protected:
 	// Outputs/Statistics
 	bool			alarmed;
 	int				pixel_diff;
-	int				alarm_pixels;
+	unsigned int			alarm_pixels;
 	int				alarm_filter_pixels;
 	int				alarm_blob_pixels;
 	int				alarm_blobs;
@@ -94,7 +94,8 @@ protected:
 
 protected:
 	void Setup( Monitor *p_monitor, int p_id, const char *p_label, ZoneType p_type, const Polygon &p_polygon, const Rgb p_alarm_rgb, CheckMethod p_check_method, int p_min_pixel_threshold, int p_max_pixel_threshold, int p_min_alarm_pixels, int p_max_alarm_pixels, const Coord &p_filter_box, int p_min_filter_pixels, int p_max_filter_pixels, int p_min_blob_pixels, int p_max_blob_pixels, int p_min_blobs, int p_max_blobs, int p_overload_frames );
-
+	void std_alarmedpixels(Image* pdiff_image, const Image* ppoly_image, unsigned int* pixel_count, unsigned int* pixel_sum);
+	
 public:
 	Zone( Monitor *p_monitor, int p_id, const char *p_label, ZoneType p_type, const Polygon &p_polygon, const Rgb p_alarm_rgb, CheckMethod p_check_method, int p_min_pixel_threshold=15, int p_max_pixel_threshold=0, int p_min_alarm_pixels=50, int p_max_alarm_pixels=75000, const Coord &p_filter_box=Coord( 3, 3 ), int p_min_filter_pixels=50, int p_max_filter_pixels=50000, int p_min_blob_pixels=10, int p_max_blob_pixels=0, int p_min_blobs=0, int p_max_blobs=0, int p_overload_frames=0 )
 	{
@@ -147,6 +148,17 @@ public:
 	static bool ParsePolygonString( const char *polygon_string, Polygon &polygon );
 	static bool ParseZoneString( const char *zone_string, int &zone_id, int &colour, Polygon &polygon );
 	static int Load( Monitor *monitor, Zone **&zones );
+	//=================================================
+    	bool CheckOverloadCount();
+    	int GetOverloadCount();
+    	void SetOverloadCount(int nOverCount);
+    	int GetOverloadFrames();
+    	void SetScore(unsigned int nScore);
+    	void SetAlarmImage(const Image* srcImage);
+
+	inline const Image *getPgImage() const { return( pg_image ); }
+	inline const Range *getRanges() const { return( ranges ); }
+
 };
 
 #endif // ZM_ZONE_H
