@@ -1,5 +1,5 @@
 //
-// ZoneMinder Analysis Daemon, $Date: 2009-04-14 21:18:57 +0100 (Tue, 14 Apr 2009) $, $Revision: 2848 $
+// ZoneMinder Analysis Daemon, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -36,7 +36,9 @@ void Usage()
 
 int main( int argc, char *argv[] )
 {
-    srand( getpid() * time( 0 ) );
+	self = argv[0];
+
+	srand( getpid() * time( 0 ) );
 
 	int id = -1;
 
@@ -87,13 +89,15 @@ int main( int argc, char *argv[] )
 		exit( 0 );
 	}
 
-	char dbg_id_string[16];
-	snprintf( dbg_id_string, sizeof(dbg_id_string), "m%d", id );
-
-	zmDbgInit( "zma", dbg_id_string, 0 );
+	char log_id_string[16];
+	snprintf( log_id_string, sizeof(log_id_string), "zma_m%d", id );
 
 	zmLoadConfig();
 
+	logInit( log_id_string );
+	
+	ssedetect();
+
 	Monitor *monitor = Monitor::Load( id, true, Monitor::ANALYSIS );
 
 	if ( monitor )
