@@ -1,5 +1,5 @@
 //
-// ZoneMinder Capture Daemon, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
+// ZoneMinder Capture Daemon, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -42,6 +42,8 @@ void Usage()
 
 int main( int argc, char *argv[] )
 {
+	self = argv[0];
+
 	srand( getpid() * time( 0 ) );
 
 	const char *device = "";
@@ -151,6 +153,8 @@ int main( int argc, char *argv[] )
 	zmLoadConfig();
 
 	logInit( log_id_string );
+	
+	ssedetect();
 
 	Monitor **monitors = 0;
 	int n_monitors = 0;
