@@ -1,5 +1,5 @@
 //
-// ZoneMinder Video Device Fixer, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
+// ZoneMinder Video Device Fixer, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -132,6 +132,8 @@ bool fixDevice( const char *device_path )
 
 int main( int argc, char *argv[] )
 {
+    self = argv[0];
+
     zmLoadConfig();
 
     logInit( "zmfix" );
@@ -166,7 +168,7 @@ int main( int argc, char *argv[] )
     // Yadda yadda
     mysql_free_result( result );
 
-    snprintf( sql, sizeof(sql), "select distinct ControlDevice from Monitors where not isnull(ControlDevice)" );
+    snprintf( sql, sizeof(sql), "select distinct ControlDevice from Monitors where not isEmpty(ControlDevice)" );
     if ( mysql_query( &dbconn, sql ) )
     {
         Error( "Can't run query: %s", mysql_error( &dbconn ) );
