@@ -1,5 +1,5 @@
 //
-// ZoneMinder Streaming Server, $Date: 2011-06-21 10:19:10 +0100 (Tue, 21 Jun 2011) $, $Revision: 3459 $
+// ZoneMinder Streaming Server, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -52,7 +52,9 @@ bool ValidateAccess( User *user, int mon_id )
 
 int main( int argc, const char *argv[] )
 {
-    srand( getpid() * time( 0 ) );
+	self = argv[0];
+
+	srand( getpid() * time( 0 ) );
 
 	enum { ZMS_MONITOR, ZMS_EVENT } source = ZMS_MONITOR;
 	enum { ZMS_JPEG, ZMS_MPEG, ZMS_RAW, ZMS_ZIP, ZMS_SINGLE } mode = ZMS_JPEG;
@@ -88,6 +90,8 @@ int main( int argc, const char *argv[] )
 	zmLoadConfig();
 
 	logInit( "zms" );
+	
+	ssedetect();
 
 	zmSetDefaultTermHandler();
 	zmSetDefaultDieHandler();
