@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web action file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
+// ZoneMinder web action file, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -287,6 +287,7 @@ if ( !empty($action) )
 
             $newFunction = validStr($_REQUEST['newFunction']);
             $newEnabled = validStr($_REQUEST['newEnabled']);
+            if ($newEnabled != "1") $newEnabled = "0";
             $oldFunction = $monitor['Function'];
             $oldEnabled = $monitor['Enabled'];
             if ( $newFunction != $oldFunction || $newEnabled != $oldEnabled )
@@ -299,8 +300,9 @@ if ( !empty($action) )
                 if ( daemonCheck() )
                 {
                     $restart = ($oldFunction == 'None') || ($newFunction == 'None') || ($newEnabled != $oldEnabled);
+                    zmaControl( $monitor, "stop" );
                     zmcControl( $monitor, $restart?"restart":"" );
-                    zmaControl( $monitor, "reload" );
+                    zmaControl( $monitor, "start" );
                 }
                 $refreshParent = true;
             }
@@ -357,6 +359,32 @@ if ( !empty($action) )
             }
             $view = 'none';
         }
+        elseif ( $action == "plugin" && isset($_REQUEST['pl']))
+        {
+           $plugin=dbEscape($_REQUEST['pl']);
+           $zid=validInt($_REQUEST['zid']);
+           $sql="SELECT * FROM PluginsConfig WHERE MonitorId='".dbEscape($mid)."' AND ZoneId='".$zid."' AND pluginName='".$plugin."'";
+           $pconfs=dbFetchAll( $sql );
+           $changes=0;
+           foreach( $pconfs as $pconf )
+           {
+              $value=$_REQUEST['pluginOpt'][$pconf['Name']];
+              if(array_key_exists($pconf['Name'], $_REQUEST['pluginOpt']) && ($pconf['Value']!=$value))
+              {
+                 dbQuery("UPDATE PluginsConfig SET Value='".dbEscape($value)."' WHERE id='".$pconf['Id']."'");
+                 $changes++;
+              }
+           }
+           if($changes>0)
+           {
+                if ( daemonCheck() )
+                {
+                    zmaControl( $mid, "restart" );
+                }
+                $refreshParent = true;
+           }
+           $view = 'none';
+        }
         elseif ( $action == "sequence" && isset($_REQUEST['smid']) )
         {
             $smid = validInt($_REQUEST['smid']);
@@ -422,7 +450,8 @@ if ( !empty($action) )
                 'Triggers' => 'set',
                 'Controllable' => 'toggle',
                 'TrackMotion' => 'toggle',
-                'Enabled' => 'toggle'
+                'Enabled' => 'toggle',
+                'DoNativeMotDet' => 'toggle'
             );
 
             $columns = getTableColumns( 'Monitors' );
@@ -530,8 +559,9 @@ if ( !empty($action) )
                     //session_write_close();
                 if ( daemonCheck() )
                 {
+                    zmaControl( $monitor, "stop" );
                     zmcControl( $monitor, "restart" );
-                    zmaControl( $monitor, "restart" );
+                    zmaControl( $monitor, "start" );
                 }
                 //daemonControl( 'restart', 'zmwatch.pl' );
                 $refreshParent = true;
