@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web function library, $Date: 2011-08-03 18:33:58 +0100 (Wed, 03 Aug 2011) $, $Revision: 3494 $
+// ZoneMinder web function library, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
@@ -648,7 +648,7 @@ function buildSelect( $name, $contents, $behaviours=false )
     foreach ( $contents as $contentValue => $contentText )
     {
 ?>
-<option value="<?= $contentValue ?>"<?php if ( $value == $contentValue ) { ?> selected="selected"<? } ?>><?= validHtmlStr($contentText) ?></option>
+<option value="<?= $contentValue ?>"<?php if ( $value == $contentValue ) { ?> selected="selected"<?php } ?>><?= validHtmlStr($contentText) ?></option>
 <?php
     }
 ?>
@@ -788,7 +788,7 @@ function getBrowser( &$browser, &$version )
     }
     else
     {
-        if ( preg_match( '/MSIE ([0-9].[0-9]{1,2})/', $_SERVER['HTTP_USER_AGENT'], $logVersion) )
+        if ( preg_match( '/MSIE (.*?);/', $_SERVER['HTTP_USER_AGENT'], $logVersion) )
         {
             $version = $logVersion[1];
             $browser = 'ie';
@@ -796,7 +796,15 @@ function getBrowser( &$browser, &$version )
         elseif ( preg_match( '/Chrome\/([0-9.]+)/', $_SERVER['HTTP_USER_AGENT'], $logVersion) )
         {
             $version = $logVersion[1];
-            $browser = 'chrome';
+            // Check for old version of Chrome with bug 5876
+            if ( $version < 7 )
+            {
+                $browser = 'oldchrome';
+            }
+            else
+            {
+                $browser = 'chrome';
+            }
         }
         elseif ( preg_match( '/Safari\/([0-9.]+)/', $_SERVER['HTTP_USER_AGENT'], $logVersion) )
         {
@@ -849,6 +857,13 @@ function isInternetExplorer()
     return( $browser == "ie" );
 }
 
+function isOldChrome()
+{
+    getBrowser( $browser, $version );
+
+    return( $browser == "oldchrome" );
+}
+
 function isChrome()
 {
     getBrowser( $browser, $version );
@@ -882,12 +897,17 @@ function canStreamIframe()
 
 function canStreamNative()
 {
-   // Chrome can display the stream, but then it blocks everything else (Chrome bug 5876)
-   return( ZM_WEB_CAN_STREAM == "yes" || ( ZM_WEB_CAN_STREAM == "auto" && (!isInternetExplorer() && !isChrome()) ) );
+   // Old versions of Chrome can display the stream, but then it blocks everything else (Chrome bug 5876)
+   return( ZM_WEB_CAN_STREAM == "yes" || ( ZM_WEB_CAN_STREAM == "auto" && (!isInternetExplorer() && !isOldChrome()) ) );
 }
 
 function canStreamApplet()
 {
+    if ( (ZM_OPT_CAMBOZOLA && !file_exists( ZM_PATH_WEB.'/'.ZM_PATH_CAMBOZOLA )) )
+    {
+        Warning ( "ZM_OPT_CAMBOZOLA is enabled, but the system cannot find ".ZM_PATH_WEB."/".ZM_PATH_CAMBOZOLA );
+    }
+
     return( (ZM_OPT_CAMBOZOLA && file_exists( ZM_PATH_WEB.'/'.ZM_PATH_CAMBOZOLA )) );
 }
 
@@ -905,7 +925,7 @@ function fixDevices()
 
 function packageControl( $command )
 {
-    $string = ZM_PATH_BIN."/zmpkg.pl $command";
+    $string = ZM_PATH_BIN.'/zmpkg.pl '.escapeshellarg( $command );
     $string .= " 2>/dev/null >&- <&- >/dev/null";
     exec( $string );
 }
@@ -2145,7 +2165,8 @@ function setDeviceStatusX10( $key, $status )
     else
     {
         // Can't connect so use script
-        $command = ZM_PATH_BIN."/zmx10.pl --command $status --unit-code $key";
+        $command = ZM_PATH_BIN.'/zmx10.pl --command '.escapeshellarg( $status );
+        $command .= ' --unit-code '.escapeshellarg( $key );
         //$command .= " 2>/dev/null >&- <&- >/dev/null";
         $x10Response = exec( $command );
     }
@@ -2166,7 +2187,7 @@ function logState()
         Logger::WARNING => array( ZM_LOG_ALERT_WAR_COUNT, ZM_LOG_ALARM_WAR_COUNT ),
     );
 
-    $sql = "select Level, count(Level) as LevelCount from Logs where Level < ".Logger::INFO." and from_unixtime(TimeKey) + interval ".ZM_LOG_CHECK_PERIOD." second > now() group by Level order by Level asc";
+    $sql = "select Level, count(Level) as LevelCount from Logs where Level < ".Logger::INFO." and TimeKey > unix_timestamp(now() - interval ".ZM_LOG_CHECK_PERIOD." second) group by Level order by Level asc";
     $counts = dbFetchAll( $sql );
 
     foreach ( $counts as $count )
@@ -2204,10 +2225,11 @@ function isVector ( &$array )
     return( true );
 }
 
-function checkJsonError()
+function checkJsonError($value)
 {
     if ( function_exists('json_last_error') )
     {
+        $value = var_export($value,true);
         switch( json_last_error() )
         {
             case JSON_ERROR_DEPTH :
@@ -2231,7 +2253,7 @@ function jsonEncode( &$value )
     if ( function_exists('json_encode') )
     {
         $string = json_encode( $value );
-        checkJsonError();
+        checkJsonError($value);
         return( $string );
     }
 
@@ -2272,7 +2294,7 @@ function jsonDecode( $value )
     if ( function_exists('json_decode') )
     {
         $object = json_decode( $value, true );
-        checkJsonError();
+        checkJsonError($value);
         return( $object );
     }
 
