@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Chinese Traditional language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
+// ZoneMinder web Chinese Traditional language file, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -76,6 +76,7 @@ setlocale( LC_TIME, 'Big5' ); //Date and time formatting 4.3.0 and after
 // Simple String Replacements
 $SLANG = array(
     '24BitColour'          => '24 位元色彩',
+    '32BitColour'          => '32 位元色彩',          // Added - 2011-06-15
     '8BitGrey'             => '8 位元灰階',
     'Action'               => 'Action',
     'Actual'               => 'Actual',
@@ -130,6 +131,7 @@ $SLANG = array(
     'BadAlarmFrameCount'   => 'Alarm frame count must be an integer of one or more',
     'BadAlarmMaxFPS'       => 'Alarm Maximum FPS must be a positive integer or floating point value',
     'BadChannel'           => 'Channel must be set to an integer of zero or more',
+    'BadColours'           => 'Target colour must be set to a valid value', // Added - 2011-06-15
     'BadDevice'            => 'Device must be set to a valid value',
     'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'            => 'Format must be set to an integer of zero or more',
@@ -266,6 +268,7 @@ $SLANG = array(
     'DonateRemindNever'    => 'No, I don\'t want to donate, never remind',
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
+    'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Download'             => '下載',
     'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => '歷時',
@@ -529,6 +532,7 @@ $SLANG = array(
     'Play'                 => 'Play',
     'PlayAll'              => '全部播放',
     'PleaseWait'           => 'Please Wait',
+    'Plugins'              => 'Plugins',
     'Point'                => '點',
     'PostEventImageBuffer' => '後置事件影像緩衝',
     'PreEventImageBuffer'  => '前置事件影像緩衝',
@@ -654,6 +658,7 @@ $SLANG = array(
     'UpdateNotNecessary'   => 'No update is necessary.',
     'Updated'              => 'Updated',                // Added - 2011-06-16
     'Upload'               => 'Upload',                 // Added - 2011-08-23
+    'UsedPlugins'	   => 'Used Plugins',
     'UseFilter'            => 'Use Filter',
     'UseFilterExprsPost'   => '&nbsp;filter&nbsp;expressions', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Use&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
