@@ -72,6 +72,7 @@
 // Simple String Replacements
 $SLANG = array(
     '24BitColour'           => '24 位彩色',
+    '32BitColour'           => '32 位彩色',          // Added - 2011-06-15
     '8BitGrey'              => '8 位灰度',
     'Action'                => '活动动作',
     'Actual'                => '实际',
@@ -126,6 +127,7 @@ $SLANG = array(
     'BadAlarmFrameCount'    => '报警帧数必须设为大于1的整数',
     'BadAlarmMaxFPS'        => '报警最大帧率必须是正整数或正浮点数',
     'BadChannel'            => '通道必须设为大于零的整数',
+    'BadColours'           => 'Target colour must be set to a valid value', // Added - 2011-06-15
     'BadDevice'             => '必须为器件设置有效值',
     'BadFPSReportInterval'  => 'FPS帧数报告间隔缓冲数必须是0以上整数',
     'BadFormat'             => '格式必须设为大于零的整数',
@@ -262,6 +264,7 @@ $SLANG = array(
     'DonateRemindNever'     => '不，我不打算捐款',
     'DonateRemindWeek'      => '现在不，1星期内再次提醒我',
     'DonateYes'             => '好，我现在就捐款',
+    'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Download'              => '下载',
     'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'              => 'Duration',
@@ -525,6 +528,7 @@ $SLANG = array(
     'Play'                  => '播放',
     'PlayAll'               => '播放全部',
     'PleaseWait'            => '请等待',
+    'Plugins'              => 'Plugins',
     'Point'                 => '点',
     'PostEventImageBuffer'  => '事件之后影像数',
     'PreEventImageBuffer'   => '时间之前影像数',
@@ -650,6 +654,7 @@ $SLANG = array(
     'UpdateNotNecessary'    => '无须更新',
     'Updated'              => 'Updated',                // Added - 2011-06-16
     'Upload'               => 'Upload',                 // Added - 2011-08-23
+    'UsedPlugins'	   => 'Used Plugins',
     'UseFilter'             => '使用筛选器',
     'UseFilterExprsPost'    => '&nbsp;筛选器&nbsp;表达式', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'     => '使用&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
