@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web UK English language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
+// ZoneMinder web UK English language file, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -72,6 +72,7 @@
 // Simple String Replacements
 $SLANG = array(
     '24BitColour'          => '24 bit barevn',
+    '32BitColour'          => '32 bit barevn',          // Added - 2011-06-15
     '8BitGrey'             => '8 bit ed kla',
     'Action'               => 'Akce',
     'Actual'               => 'Skuten',
@@ -126,6 +127,7 @@ $SLANG = array(
     'BadAlarmFrameCount'   => 'Alarm frame count must be an integer of one or more',
     'BadAlarmMaxFPS'       => 'Alarm Maximum FPS must be a positive integer or floating point value',
     'BadChannel'           => 'Channel must be set to an integer of zero or more',
+    'BadColours'           => 'Target colour must be set to a valid value', // Added - 2011-06-15
     'BadDevice'            => 'Device must be set to a valid value',
     'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'            => 'Format must be set to an integer of zero or more',
@@ -262,6 +264,7 @@ $SLANG = array(
     'DonateRemindNever'    => 'Ne, nechci podpoit ZoneMinder, nepipomnat',
     'DonateRemindWeek'     => 'Nyn ne, pipomenout za tden',
     'DonateYes'            => 'Ano, chcit podpoit ZoneMinder nyn',
+    'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Download'             => 'Sthnout',
     'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Prbh',
@@ -525,6 +528,7 @@ $SLANG = array(
     'Play'                 => 'Play',
     'PlayAll'              => 'Pehrt ve',
     'PleaseWait'           => 'Prosm ekejte',
+    'Plugins'              => 'Plugins',
     'Point'                => 'Point',
     'PostEventImageBuffer' => 'Pozznamov bufer',
     'PreEventImageBuffer'  => 'Pedzznamov bufer',
@@ -650,6 +654,7 @@ $SLANG = array(
     'UpdateNotNecessary'   => 'Update nen poteba.',
     'Updated'              => 'Updated',                // Added - 2011-06-16
     'Upload'               => 'Upload',                 // Added - 2011-08-23
+    'UsedPlugins'	   => 'Used Plugins',
     'UseFilter'            => 'Pout filtr',
     'UseFilterExprsPost'   => '&nbsp;vraz', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Pout&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
