@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web German language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
+// ZoneMinder web German language file, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -72,6 +72,7 @@
 // Simple String Replacements
 $SLANG = array(
     '24BitColour'          => '24-Bit-Farbe',
+    '32BitColour'          => '32-Bit-Farbe',          // Added - 2011-06-15
     '8BitGrey'             => '8-Bit-Grau',
     'Action'               => 'Aktion',
     'Actual'               => 'Original',
@@ -126,6 +127,7 @@ $SLANG = array(
     'BadAlarmFrameCount'   => 'Die Bildanzahl muss ganzzahlig 1 oder gr&ouml;&szlig;er sein',
     'BadAlarmMaxFPS'       => 'Alarm-Maximum-FPS muss eine positive Ganzzahl oder eine Gleitkommazahl sein',
     'BadChannel'           => 'Der Kanal muss ganzzahlig 0 oder gr&ouml;&szlig;er sein',
+    'BadColours'           => 'Target colour must be set to a valid value', // Added - 2011-06-15
     'BadDevice'            => 'Das Ger&auml;t muss eine g&uuml;ltige Systemresource sein',
     'BadFPSReportInterval' => 'Der FPS-Intervall-Puffer-Z&auml;hler muss ganzzahlig 0 oder gr&ouml;&szlig;er sein',
     'BadFormat'            => 'Das Format muss ganzzahlig 0 oder gr&ouml;&szlig;er sein',
@@ -262,6 +264,7 @@ $SLANG = array(
     'DonateRemindNever'    => 'Nein, ich m&ouml;chte nicht spenden, niemals erinnern.',
     'DonateRemindWeek'     => 'Noch nicht, erinnere mich in einer Woche noch mal.',
     'DonateYes'            => 'Ja, ich m&ouml;chte jetzt spenden.',
+    'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Download'             => 'Download',
     'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Dauer',
@@ -525,6 +528,7 @@ $SLANG = array(
     'Play'                 => 'Abspielen',
     'PlayAll'              => 'Alle zeigen',
     'PleaseWait'           => 'Bitte warten',
+    'Plugins'              => 'Plugins',
     'Point'                => 'Punkt',
     'PostEventImageBuffer' => 'Nachereignispuffer',
     'PreEventImageBuffer'  => 'Vorereignispuffer',
@@ -650,6 +654,7 @@ $SLANG = array(
     'UpdateNotNecessary'   => 'Es ist keine Aktualisierung verf&uuml;gbar.',
     'Updated'              => 'Updated',                // Added - 2011-06-16
     'Upload'               => 'Upload',                 // Added - 2011-08-23
+    'UsedPlugins'	   => 'Used Plugins',
     'UseFilter'            => 'Benutze Filter',
     'UseFilterExprsPost'   => '&nbsp;Filter&nbsp;Ausdr&uuml;cke', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Benutze&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
