@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Danish language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
+// ZoneMinder web Danish language file, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -73,6 +73,7 @@ header( "Content-Type: text/html; charset=windows-1252" );
 // Simple String Replacements
 $SLANG = array(
     '24BitColour'          => '24 bit farve',
+    '32BitColour'          => '32 bit farve',          // Added - 2011-06-15
     '8BitGrey'             => '8 bit greyscale',
     'Action'               => 'Action',
     'Actual'               => 'Aktuel',
@@ -127,6 +128,7 @@ $SLANG = array(
     'BadAlarmFrameCount'   => 'Alarm frame count must be an integer of one or more',
     'BadAlarmMaxFPS'       => 'Alarm Maximum FPS must be a positive integer or floating point value',
     'BadChannel'           => 'Channel must be set to an integer of zero or more',
+    'BadColours'           => 'Target colour must be set to a valid value', // Added - 2011-06-15
     'BadDevice'            => 'Device must be set to a valid value',
     'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'            => 'Format must be set to an integer of zero or more',
@@ -263,6 +265,7 @@ $SLANG = array(
     'DonateRemindNever'    => 'No, I don\'t want to donate, never remind',
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
+    'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Download'             => 'Download',
     'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Forlb',
@@ -526,6 +529,7 @@ $SLANG = array(
     'Play'                 => 'Play',
     'PlayAll'              => 'Afspil Alle',
     'PleaseWait'           => 'Vent venligst',
+    'Plugins'              => 'Plugins',
     'Point'                => 'Point',
     'PostEventImageBuffer' => 'Efter Event Billed Buffer',
     'PreEventImageBuffer'  => 'Fr Event Billed Buffer',
@@ -651,6 +655,7 @@ $SLANG = array(
     'UpdateNotNecessary'   => 'Ingen updatering er ndvendig.',
     'Updated'              => 'Updated',                // Added - 2011-06-16
     'Upload'               => 'Upload',                 // Added - 2011-08-23
+    'UsedPlugins'	   => 'Used Plugins',
     'UseFilter'            => 'Brug Filter',
     'UseFilterExprsPost'   => '&nbsp;filter&nbsp;expressions', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Brug&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
