@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web UK English language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
+// ZoneMinder web UK English language file, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -81,6 +81,7 @@ $SLANG = array(
     'More'                  => 'More',
     'Clear'                 => 'Clear',
     '24BitColour'           => '24 bit colour',
+    '32BitColour'           => '32 bit colour',
     '8BitGrey'              => '8 bit greyscale',
     'Action'                => 'Action',
     'Actual'                => 'Actual',
@@ -148,6 +149,7 @@ $SLANG = array(
     'BadMaxFPS'             => 'Maximum FPS must be a positive integer or floating point value',
     'BadNameChars'          => 'Names may only contain alphanumeric characters plus hyphen and underscore',
     'BadPalette'            => 'Palette must be set to a valid value',
+    'BadColours'            => 'Target colour must be set to a valid value',
     'BadPath'               => 'Path must be set to a valid value',
     'BadPort'               => 'Port must be set to a valid number',
     'BadPostEventCount'     => 'Post event image count must be an integer of zero or more',
@@ -269,6 +271,7 @@ $SLANG = array(
     'DonateRemindNever'     => 'No, I don\'t want to donate, never remind',
     'DonateRemindWeek'      => 'Not yet, remind again in 1 week',
     'DonateYes'             => 'Yes, I\'d like to donate now',
+    'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Download'              => 'Download',
     'DuplicateMonitorName'  => 'Duplicate Monitor Name',
     'Duration'              => 'Duration',
@@ -526,6 +529,7 @@ $SLANG = array(
     'Pixels'                => 'pixels',
     'PlayAll'               => 'Play All',
     'Play'                  => 'Play',
+    'Plugins'               => 'Plugins',
     'PleaseWait'            => 'Please Wait',
     'Point'                 => 'Point',
     'PostEventImageBuffer'  => 'Post Event Image Count',
@@ -651,6 +655,7 @@ $SLANG = array(
     'Update'                => 'Update',
     'Upload'                => 'Upload',
     'Updated'               => 'Updated',
+    'UsedPlugins'	   => 'Used Plugins',
     'UseFilterExprsPost'    => '&nbsp;filter&nbsp;expressions', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'     => 'Use&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
     'UseFilter'             => 'Use Filter',
