@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Argentinian Spanish language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
+// ZoneMinder web Argentinian Spanish language file, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -23,6 +23,7 @@
 // Simple String Replacements
 $SLANG = array(
     '24BitColour'          => 'Color 24 bits',
+    '32BitColour'          => 'Color 32 bits',          // Added - 2011-06-15
     '8BitGrey'             => 'Grises 8 bits',
     'Action'               => 'Action',
     'Actual'               => 'Actual',
@@ -77,6 +78,7 @@ $SLANG = array(
     'BadAlarmFrameCount'   => 'Alarm frame count must be an integer of one or more',
     'BadAlarmMaxFPS'       => 'Alarm Maximum FPS must be a positive integer or floating point value',
     'BadChannel'           => 'Channel must be set to an integer of zero or more',
+    'BadColours'           => 'Target colour must be set to a valid value', // Added - 2011-06-15
     'BadDevice'            => 'Device must be set to a valid value',
     'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'            => 'Format must be set to an integer of zero or more',
@@ -213,6 +215,7 @@ $SLANG = array(
     'DonateRemindNever'    => 'No, I don\'t want to donate, never remind',
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
+    'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Download'             => 'Download',
     'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Duracin',
@@ -476,6 +479,7 @@ $SLANG = array(
     'Play'                 => 'Play',
     'PlayAll'              => 'Play All',
     'PleaseWait'           => 'Espere por favor',
+    'Plugins'              => 'Plugins',
     'Point'                => 'Point',
     'PostEventImageBuffer' => 'Buffer Imagenes despues evento',
     'PreEventImageBuffer'  => 'Buffer Imagenes antes evento',
@@ -601,6 +605,7 @@ $SLANG = array(
     'UpdateNotNecessary'   => 'No se requiere Actualizacin',
     'Updated'              => 'Updated',                // Added - 2011-06-16
     'Upload'               => 'Upload',                 // Added - 2011-08-23
+    'UsedPlugins'	   => 'Used Plugins',
     'UseFilter'            => 'Usar Filtro',
     'UseFilterExprsPost'   => '&nbsp;filtrar&nbsp;sentencias', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Utilizar&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
