@@ -68,6 +68,7 @@ header( "Content-Type: text/html; charset=UTF-8" );
 // Simple String Replacements
 $SLANG = array(
     '24BitColour'           => '24 bit colour',
+    '32BitColour'           => '32 bit colour',          // Added - 2011-06-15
     '8BitGrey'              => '8 bit greyscale',
     'Action'                => 'Action',
     'Actual'                => 'Actual',
@@ -122,6 +123,7 @@ $SLANG = array(
     'BadAlarmFrameCount'    => 'Alarm frame count must be an integer of one or more',
     'BadAlarmMaxFPS'        => 'Alarm Maximum FPS must be a positive integer or floating point value',
     'BadChannel'            => 'Channel must be set to an integer of zero or more',
+    'BadColours'           => 'Target colour must be set to a valid value', // Added - 2011-06-15
     'BadDevice'             => 'Device must be set to a valid value',
     'BadFPSReportInterval'  => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'             => 'Format must be set to a valid value',
@@ -521,6 +523,7 @@ $SLANG = array(
     'Play'                  => 'Play',
     'PlayAll'               => 'Play All',
     'PleaseWait'            => 'Please Wait',
+    'Plugins'              => 'Plugins',
     'Point'                 => 'Point',
     'PostEventImageBuffer'  => 'Post Event Image Count',
     'PreEventImageBuffer'   => 'Pre Event Image Count',
