@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web UK French language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
+// ZoneMinder web UK French language file, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -72,6 +72,7 @@
 // Simple String Replacements
 $SLANG = array(
     '24BitColour'          => 'Couleur 24 bit',
+    '32BitColour'          => 'Couleur 32 bit',          // Added - 2011-06-15
     '8BitGrey'             => 'Gris 8 bit',
     'Action'               => 'Action',
     'Actual'               => 'Rel',
@@ -126,6 +127,7 @@ $SLANG = array(
     'BadAlarmFrameCount'   => 'Alarm frame count must be an integer of one or more',
     'BadAlarmMaxFPS'       => 'Alarm Maximum FPS must be a positive integer or floating point value',
     'BadChannel'           => 'Channel must be set to an integer of zero or more',
+    'BadColours'           => 'Target colour must be set to a valid value', // Added - 2011-06-15
     'BadDevice'            => 'Device must be set to a valid value',
     'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'            => 'Format must be set to an integer of zero or more',
@@ -262,6 +264,7 @@ $SLANG = array(
     'DonateRemindNever'    => 'No, I don\'t want to donate, never remind',
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
+    'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Download'             => 'Download',
     'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Dure',
@@ -525,6 +528,7 @@ $SLANG = array(
     'Play'                 => 'Play',
     'PlayAll'              => 'Play All',
     'PleaseWait'           => 'Attendez',
+    'Plugins'              => 'Plugins',
     'Point'                => 'Point',
     'PostEventImageBuffer' => 'Post Event Image Count',
     'PreEventImageBuffer'  => 'Pre Event Image Count',
@@ -650,6 +654,7 @@ $SLANG = array(
     'UpdateNotNecessary'   => 'Pas de mise  jour dispo.',
     'Updated'              => 'Updated',                // Added - 2011-06-16
     'Upload'               => 'Upload',                 // Added - 2011-08-23
+    'UsedPlugins'	   => 'Used Plugins',
     'UseFilter'            => 'Util. Filtre',
     'UseFilterExprsPost'   => '&nbsp;filter&nbsp;expressions', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Util.&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
