@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Italian language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
+// ZoneMinder web Italian language file, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -77,6 +77,7 @@
 // Simple String Replacements
 $SLANG = array(
     '24BitColour'          => 'colori a 24 bit',
+    '32BitColour'          => 'colori a 32 bit',          // Added - 2011-06-15
     '8BitGrey'             => '8 bit scala di grigio',
     'Action'               => 'Azione',
     'Actual'               => 'Attuale',
@@ -131,6 +132,7 @@ $SLANG = array(
     'BadAlarmFrameCount'   => 'Il numero di frame di un allarme deve essere un numero intero superiore a uno',
     'BadAlarmMaxFPS'       => 'Il numero massimo di FPS dell\'allarme deve essere un numero intero positivo o un valore in virgola mobile',
     'BadChannel'           => 'Il canale deve essere settato con un numero intero uguale o maggiore di zero',
+    'BadColours'           => 'Target colour must be set to a valid value', // Added - 2011-06-15
     'BadDevice'            => 'Il dispositivo deve essere impostato con un valore valido',
     'BadFPSReportInterval' => 'L\'intervallo di FPS per i report deve essere un numero intero superiore a 0',
     'BadFormat'            => 'Il formato deve essere impostato con un numero intero come 0 o maggiore',
@@ -267,6 +269,7 @@ $SLANG = array(
     'DonateRemindNever'    => 'No, io non voglio donare, non lo faro\' mai',
     'DonateRemindWeek'     => 'Non ancora, ricordamelo ancora tra 1 settimana',
     'DonateYes'            => 'Si,mi piacerebbe donare qualcosa ora',
+    'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Download'             => 'Download',
     'DuplicateMonitorName' => 'Il nome del monitor e\' gia\' presente', // Added - 2009-03-31
     'Duration'             => 'Durata',
@@ -530,6 +533,7 @@ $SLANG = array(
     'Play'                 => 'Play',
     'PlayAll'              => 'Vedi tutti',
     'PleaseWait'           => 'Attendere prego',
+    'Plugins'              => 'Plugins',
     'Point'                => 'Punto',
     'PostEventImageBuffer' => 'Buffer di immagini Dopo Evento',
     'PreEventImageBuffer'  => 'Buffer di immagini Pre Evento',
@@ -655,6 +659,7 @@ $SLANG = array(
     'UpdateNotNecessary'   => 'Nessun aggiornamento necessario.',
     'Updated'              => 'Updated',                // Added - 2011-06-16
     'Upload'               => 'Upload',                 // Added - 2011-08-23
+    'UsedPlugins'	   => 'Used Plugins',
     'UseFilter'            => 'Usa Filtro',
     'UseFilterExprsPost'   => '&nbsp;espressioni&nbsp;filtri', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Usa&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
