@@ -12,6 +12,7 @@
 // Simple String Replacements
 $SLANG = array(
     '24BitColour'          => 'cor 24 bits',
+    '32BitColour'          => 'cor 32 bits',          // Added - 2011-06-15
     '8BitGrey'             => 'cinza 8 bits',
     'Action'               => 'Action',
     'Actual'               => 'Atual',
@@ -66,6 +67,7 @@ $SLANG = array(
     'BadAlarmFrameCount'   => 'Alarm frame count must be an integer of one or more',
     'BadAlarmMaxFPS'       => 'Alarm Maximum FPS must be a positive integer or floating point value',
     'BadChannel'           => 'Channel must be set to an integer of zero or more',
+    'BadColours'           => 'Target colour must be set to a valid value', // Added - 2011-06-15
     'BadDevice'            => 'Device must be set to a valid value',
     'BadFPSReportInterval' => 'FPS report interval buffer count must be an integer of 0 or more',
     'BadFormat'            => 'Format must be set to an integer of zero or more',
@@ -202,6 +204,7 @@ $SLANG = array(
     'DonateRemindNever'    => 'No, I don\'t want to donate, never remind',
     'DonateRemindWeek'     => 'Not yet, remind again in 1 week',
     'DonateYes'            => 'Yes, I\'d like to donate now',
+    'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Download'             => 'Download',
     'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Durao',
@@ -465,6 +468,7 @@ $SLANG = array(
     'Play'                 => 'Play',
     'PlayAll'              => 'Play All',
     'PleaseWait'           => 'Por Favor Espere',
+    'Plugins'              => 'Plugins',
     'Point'                => 'Point',
     'PostEventImageBuffer' => 'Buffer de imagem ps evento',
     'PreEventImageBuffer'  => 'Buffer de imagem pr evento',
@@ -590,6 +594,7 @@ $SLANG = array(
     'UpdateNotNecessary'   => 'No  necessrio update.',
     'Updated'              => 'Updated',                // Added - 2011-06-16
     'Upload'               => 'Upload',                 // Added - 2011-08-23
+    'UsedPlugins'	   => 'Used Plugins',
     'UseFilter'            => 'Use Filtro',
     'UseFilterExprsPost'   => '&nbsp;expresses&nbsp;de&nbsp;filtragem', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Use&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
