@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web Swedish language file, $Date: 2011-08-23 15:10:20 +0100 (Tue, 23 Aug 2011) $, $Revision: 3500 $
+// ZoneMinder web Swedish language file, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -73,6 +73,7 @@
 // Simple String Replacements
 $SLANG = array(
     '24BitColour'          => '24 bitars frg',
+    '32BitColour'          => '32 bitars frg',          // Added - 2011-06-15
     '8BitGrey'             => '8 bit grskala',
     'Action'               => 'Action',
     'Actual'               => 'Verklig',
@@ -127,6 +128,7 @@ $SLANG = array(
     'BadAlarmFrameCount'   => 'Ramantalet fr larm mste vara ett heltal, minsta vrdet r 1',
     'BadAlarmMaxFPS'       => 'Larm fr bilder/s mste vara ett positivt heltal eller ett flyttal',
     'BadChannel'           => 'Kanalen mste vara ett heltal, noll eller hgre',
+    'BadColours'           => 'Target colour must be set to a valid value', // Added - 2011-06-15
     'BadDevice'            => 'Enheten mste sttas till ett giltigt vrde',
     'BadFPSReportInterval' => 'Buffern fr ramintervallrapporten mste vara ett heltal p minst 0 eller hgre',
     'BadFormat'            => 'Formatet mste vara ett heltal, noll eller hgre',
@@ -263,6 +265,7 @@ $SLANG = array(
     'DonateRemindNever'    => 'Nej, Jag vill inte donera, pminn mig inte mer',
     'DonateRemindWeek'     => 'Inte n, pminn om 1 vecka',
     'DonateYes'            => 'Ja, jag vill grna donera nu',
+    'DoNativeMotionDetection'=> 'Do Native Motion Detection',
     'Download'             => 'Ladda ner',
     'DuplicateMonitorName' => 'Duplicate Monitor Name', // Added - 2009-03-31
     'Duration'             => 'Lngd',
@@ -526,6 +529,7 @@ $SLANG = array(
     'Play'                 => 'Spela',
     'PlayAll'              => 'Visa alla',
     'PleaseWait'           => 'Vnta...',
+    'Plugins'              => 'Plugins',
     'Point'                => 'Punkt',
     'PostEventImageBuffer' => 'Post Event Image Count',
     'PreEventImageBuffer'  => 'Pre Event Image Count',
@@ -651,6 +655,7 @@ $SLANG = array(
     'UpdateNotNecessary'   => 'Ingen uppdatering behvs.',
     'Updated'              => 'Updated',                // Added - 2011-06-16
     'Upload'               => 'Upload',                 // Added - 2011-08-23
+    'UsedPlugins'	   => 'Used Plugins',
     'UseFilter'            => 'Anvnd filter',
     'UseFilterExprsPost'   => '&nbsp;filter&nbsp;expressions', // This is used at the end of the phrase 'use N filter expressions'
     'UseFilterExprsPre'    => 'Anvnd&nbsp;', // This is used at the beginning of the phrase 'use N filter expressions'
