@@ -9,7 +9,7 @@ var controlOptions = new Object();
 <?php
     global $controlTypes;
     $controlTypes = array( ''=>$SLANG['None'] );
-    $sql = "select * from Controls where Type = '".$monitor['Type']."'";
+    $sql = "select * from Controls where Type = '".$newMonitor['Type']."'";
     foreach( dbFetchAll( $sql ) as $row )
     {
         $controlTypes[$row['Id']] = $row['Name'];
@@ -66,10 +66,12 @@ function validateForm( form )
         errors[errors.length] = "<?= $SLANG['BadMaxFPS'] ?>";
     if ( form.elements['newMonitor[AlarmMaxFPS]'].value && !(parseFloat(form.elements['newMonitor[AlarmMaxFPS]'].value) > 0 ) )
         errors[errors.length] = "<?= $SLANG['BadAlarmMaxFPS'] ?>";
-    if ( !form.elements['newMonitor[RefBlendPerc]'].value || !(parseInt(form.elements['newMonitor[RefBlendPerc]'].value) > 0 ) )
+    if ( !form.elements['newMonitor[RefBlendPerc]'].value || (parseInt(form.elements['newMonitor[RefBlendPerc]'].value) > 100 ) || (parseInt(form.elements['newMonitor[RefBlendPerc]'].value) < 0 ) )
         errors[errors.length] = "<?= $SLANG['BadRefBlendPerc'] ?>";
     if ( form.elements['newMonitor[Type]'].value == 'Local' )
     {
+        if ( !form.elements['newMonitor[Palette]'].value || !form.elements['newMonitor[Palette]'].value.match( /^\d+$/ ) )
+            errors[errors.length] = "<?= $SLANG['BadPalette'] ?>";
         if ( !form.elements['newMonitor[Device]'].value )
             errors[errors.length] = "<?= $SLANG['BadDevice'] ?>";
         if ( !form.elements['newMonitor[Channel]'].value || !form.elements['newMonitor[Channel]'].value.match( /^\d+$/ ) )
@@ -91,8 +93,8 @@ function validateForm( form )
         if ( !form.elements['newMonitor[Path]'].value )
             errors[errors.length] = "<?= $SLANG['BadPath'] ?>";
     }
-    if ( !form.elements['newMonitor[Palette]'].value || !form.elements['newMonitor[Palette]'].value.match( /^\d+$/ ) )
-        errors[errors.length] = "<?= $SLANG['BadPalette'] ?>";
+    if ( !form.elements['newMonitor[Colours]'].value || (parseInt(form.elements['newMonitor[Colours]'].value) != 1 && parseInt(form.elements['newMonitor[Colours]'].value) != 3 && parseInt(form.elements['newMonitor[Colours]'].value) != 4 ) )
+        errors[errors.length] = "<?= $SLANG['BadColours'] ?>";
     if ( !form.elements['newMonitor[Width]'].value || !(parseInt(form.elements['newMonitor[Width]'].value) > 0 ) )
         errors[errors.length] = "<?= $SLANG['BadWidth'] ?>";
     if ( !form.elements['newMonitor[Height]'].value || !(parseInt(form.elements['newMonitor[Height]'].value) > 0 ) )
