@@ -1,6 +1,6 @@
 <?php
 //
-// ZoneMinder web event details view file, $Date: 2010-02-23 09:12:12 +0000 (Tue, 23 Feb 2010) $, $Revision: 3031 $
+// ZoneMinder web event details view file, $Date$, $Revision$
 // Copyright (C) 2001-2008 Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
@@ -24,7 +24,7 @@ if ( !canView( 'Events' ) )
     return;
 }
 
-$event = dbFetchOne( "select E.*,M.Name as MonitorName,M.Width,M.Height from Events as E, Monitors as M where E.Id = '".dbEscape($_REQUEST['eid'])."' and E.MonitorId = M.Id" );
+$event = dbFetchOne( "select E.*,M.Name as MonitorName from Events as E, Monitors as M where E.Id = '".dbEscape($_REQUEST['eid'])."' and E.MonitorId = M.Id" );
 $frame = dbFetchOne( "select * from Frames where EventID = '".dbEscape($_REQUEST['eid'])."' and Score = '".$event['MaxScore']."'" );
 
 $scale = getDeviceScale( $event['Width'], $event['Height'], 2.2 );
